@@ -168,20 +168,28 @@ export const newTracker = () => {
          */
         registerPersonalizationObject: function (personalization, variants, ajax, resultCallback) {
             var target = personalization.id;
-            wem._registerPersonalizationCallback(personalization, function (result) {
-                var successfulFilters = [];
-                for (var i = 0; i < result.length; i++) {
-                    successfulFilters.push(variants[result[i]]);
-                }
-
+            wem._registerPersonalizationCallback(personalization, function (result, additionalResultInfos) {
                 var selectedFilter = null;
-                if (successfulFilters.length > 0) {
-                    selectedFilter = successfulFilters[0];
-                    var minPos = successfulFilters[0].position;
-                    if (minPos >= 0) {
-                        for (var j = 1; j < successfulFilters.length; j++) {
-                            if (successfulFilters[j].position < minPos) {
-                                selectedFilter = successfulFilters[j];
+                var successfulFilters = [];
+
+                var inControlGroup = additionalResultInfos && additionalResultInfos.inControlGroup;
+                // In case of control group Unomi is not resolving any strategy or fallback for us. So we have to do the fallback here.
+                if (inControlGroup && personalization.strategyOptions && personalization.strategyOptions.fallback) {
+                    selectedFilter = variants[personalization.strategyOptions.fallback];
+                    successfulFilters.push(selectedFilter);
+                } else {
+                    for (var i = 0; i < result.length; i++) {
+                        successfulFilters.push(variants[result[i]]);
+                    }
+
+                    if (successfulFilters.length > 0) {
+                        selectedFilter = successfulFilters[0];
+                        var minPos = successfulFilters[0].position;
+                        if (minPos >= 0) {
+                            for (var j = 1; j < successfulFilters.length; j++) {
+                                if (successfulFilters[j].position < minPos) {
+                                    selectedFilter = successfulFilters[j];
+                                }
                             }
                         }
                     }
@@ -201,7 +209,7 @@ export const newTracker = () => {
                         }
 
                         // we now add control group information to event if the user is in the control group.
-                        if (wem._isInControlGroup(target)) {
+                        if (inControlGroup) {
                             console.info('[WEM] Profile is in control group for target: ' + target + ', adding to personalization event...');
                             selectedFilter.event.target.properties.inControlGroup = true;
                             if (selectedFilter.event.target.properties.variants) {
@@ -729,6 +737,19 @@ export const newTracker = () => {
             document.dispatchEvent(event);
         },
 
+        /**
+         * Fill the wem.digitalData.displayedVariants with the javascript event passed as parameter
+         * @param {object} jsEvent javascript event
+         * @private
+         * @return {undefined}
+         */
+        _fillDisplayedVariants: (jsEvent) => {
+            if (!wem.digitalData.displayedVariants) {
+                wem.digitalData.displayedVariants = [];
+            }
+            wem.digitalData.displayedVariants.push(jsEvent);
+        },
+
         /**
          * This is an utility function to get current url parameter value
          *
@@ -939,6 +960,10 @@ export const newTracker = () => {
                         }
                     };
 
+                    if (experienceUnomiEvent.eventType === 'personalizationEvent') {
+                        jsEventDetail.wrapper.inControlGroup = experienceUnomiEvent.target.properties.inControlGroup;
+                    }
+                    wem._fillDisplayedVariants(jsEventDetail);
                     wem.dispatchJSEvent('displayWemVariant', false, false, jsEventDetail);
                 }
             }
@@ -1116,7 +1141,14 @@ export const newTracker = () => {
 
                 if (wem.digitalData.personalizationCallback) {
                     for (var j = 0; j < wem.digitalData.personalizationCallback.length; j++) {
-                        wem.digitalData.personalizationCallback[j].callback(wem.cxs.personalizations[wem.digitalData.personalizationCallback[j].personalization.id]);
+                        if (wem.cxs.personalizationResults) {
+                            // Since Unomi 2.1.0 personalization results are available with more infos
+                            var personalizationResult = wem.cxs.personalizationResults[wem.digitalData.personalizationCallback[j].personalization.id];
+                            wem.digitalData.personalizationCallback[j].callback(personalizationResult.contentIds, personalizationResult.additionalResultInfos);
+                        } else {
+                            // probably a version older than Unomi 2.1.0, fallback to old personalization results
+                            wem.digitalData.personalizationCallback[j].callback(wem.cxs.personalizations[wem.digitalData.personalizationCallback[j].personalization.id]);
+                        }
                     }
                 }
             }
@@ -1395,28 +1427,6 @@ export const newTracker = () => {
          */
         _isObject: function (obj) {
             return obj && typeof obj === 'object';
-        },
-
-        /**
-         * Utility function used to check if the current id is contains in any Unomi control group
-         * @param {string} id the id to check
-         * @private
-         * @return {boolean} true if the id is found in a control group, false otherwise
-         */
-        _isInControlGroup: function (id) {
-            if (wem.cxs.profileProperties && wem.cxs.profileProperties.unomiControlGroups) {
-                let controlGroup = wem.cxs.profileProperties.unomiControlGroups.find(controlGroup => controlGroup.id === id);
-                if (controlGroup) {
-                    return true;
-                }
-            }
-            if (wem.cxs.sessionProperties && wem.cxs.sessionProperties.unomiControlGroups) {
-                let controlGroup = wem.cxs.sessionProperties.unomiControlGroups.find(controlGroup => controlGroup.id === id);
-                if (controlGroup) {
-                    return true;
-                }
-            }
-            return false;
         }
     };
 
